==> booking_card_layout-0.0.3.tar.gz: lib/hotel_card_layout.dart <==
library booking_card_layout;

import 'package:booking_card_layout/constants.dart';
import 'package:booking_card_layout/tv_theme.dart';
import 'package:flutter/material.dart';
import 'package:font_awesome_flutter/font_awesome_flutter.dart';
import 'package:google_fonts/google_fonts.dart';
import 'package:intl/intl.dart';

Widget HotelCardLayout(String referenceNo,String city,String assCode,DateTime arrivalDatetime,DateTime depDatetime,String statusCompany,List<dynamic>people,String statusTv,String userName){
  return Container(
    padding: const EdgeInsets.all(2),
    child: Card(
      elevation: 5,
      surfaceTintColor: TVTheme.whiteColor,
      child: Column(
        crossAxisAlignment: CrossAxisAlignment.start,
        children: [
          Container(
            height: Constants.taxiCardTop,
            color: TVTheme.blackColor,
            child: Row(
              mainAxisAlignment: MainAxisAlignment.spaceBetween,
              children: [
                Padding(
                  padding: const EdgeInsets.only(left: 10),
                  child: Text(referenceNo.toString(),style: GoogleFonts.lato(fontWeight: FontWeight.w600,color: TVTheme.primaryColor,fontSize: Constants.subHeader),),
                ),
                Padding(
                  padding: const EdgeInsets.only(right: 10),
                  child: Text(city.toString(),style: GoogleFonts.lato(fontWeight: FontWeight.w600,color: TVTheme.primaryColor,fontSize: Constants.subHeader),),
                ),
              ],
            ),
          ),
          Padding(
            padding: const EdgeInsets.only(left: 10),
            child: Text("Assessment Code - ${assCode.toString()}",style: GoogleFonts.lato(fontWeight: FontWeight.w500,color: TVTheme.blackColor,fontSize: Constants.header)),
          ),
          const Divider(height: 2,),
          Row(
            children: [
              Expanded(
                  flex: 3,
                  child: Row(
                    children: [
                      Expanded(
                          flex: 3,
                          child: Column(
                            children: [
                              Icon(FontAwesomeIcons.hotel,size: Constants.iconSize,),
                              Text("Arrival",
                                style: GoogleFonts.lato(fontSize: Constants.subHeader),
                              ),
                            ],
                          )
                      ),
                      Expanded(
                        flex:5,
                        child: Column(
                          crossAxisAlignment: CrossAxisAlignment.start,
                          children: [
                            Text("${arrivalDatetime.day} ",style: GoogleFonts.lato(fontWeight: FontWeight.w600,fontSize: Constants.title),),
                            Text("${arrivalDatetime.month} ${arrivalDatetime.year}",style: GoogleFonts.lato(fontSize: Constants.subHeader),),
                            Text(DateFormat.jm().format(arrivalDatetime),style: GoogleFonts.lato(fontSize: Constants.subHeader),),
                          ],
                        ),
                      ),
                    ],
                  )
              ),
              const SizedBox(width: 2,),
              Expanded(
                  flex: 3,
                  child: Row(
                    children: [
                      Expanded(
                          flex: 3,
                          child: Column(
                            children: [
                              Icon(FontAwesomeIcons.hotel,size: Constants.iconSize,),
                              Text("Departure",style: GoogleFonts.lato(fontSize: Constants.subHeader),),
                            ],
                          )
                      ),
                      Expanded(
                        flex:5,
                        child: Column(
                          crossAxisAlignment: CrossAxisAlignment.start,
                          children: [
                            Text("${depDatetime.day} ",style: GoogleFonts.lato(fontWeight: FontWeight.w600,fontSize: Constants.title),),
                            Text("${depDatetime.month} ${depDatetime.year}",style: GoogleFonts.lato(fontSize: Constants.subHeader),),
                            Text(DateFormat.jm().format(depDatetime),style: GoogleFonts.lato(fontSize: Constants.subHeader),),
                          ],
                        ),
                      ),
                    ],
                  )
              ),
            ],
          ),
          const Divider(height: 2,),
          Row(
            children: [
              Expanded(
                flex: 3,
                child: Row(
                  mainAxisAlignment: MainAxisAlignment.start,
                  crossAxisAlignment: CrossAxisAlignment.start,
                  children: [
                    Expanded(
                        flex: 3,
                        child: Container(
                            padding: const EdgeInsets.only(left: 10),
                            alignment:Alignment.topLeft,
                            child: Text(
                                "Approver",
                                style: GoogleFonts.lato(fontSize: Constants.subHeader)
                            )
                        )),
                    Expanded(
                        flex: 4,
                        child: Container(
                            alignment:Alignment.topLeft,
                            child: Text(
                                statusCompany.toString(),
                                overflow: TextOverflow.ellipsis,
                                style: GoogleFonts.lato(
                                    textStyle: TextStyle(
                                        fontWeight: FontWeight.w600,
                                        fontSize: Constants.subHeader
                                    )
                                )
                            )
                        )
                    ),
                  ],
                ),
              ),

              Expanded(
                flex: 3,
                child:GestureDetector(
                  onTap: (){
                    //showEmployeeDetails(people);
                  },
                  child: Row(
                    mainAxisAlignment: MainAxisAlignment.center,
                    crossAxisAlignment: CrossAxisAlignment.start,
                    children: [
                      Expanded(
                          flex: 3,
                          child: Container(
                              padding: const EdgeInsets.only(left: 10),
                              alignment:Alignment.topLeft,
                              child: Text(
                                  "People",
                                  style: GoogleFonts.lato(fontSize: Constants.subHeader)
                              )
                          )
                      ),
                      Expanded(
                          flex: 4,
                          child: Row(
                            children: [
                              Container(
                                  padding: const EdgeInsets.only(right: 5),
                                  alignment:Alignment.topLeft,
                                  child: Text(
                                      people!.length.toString(),
                                      style: GoogleFonts.lato(fontSize: Constants.subHeader, fontWeight: FontWeight.w600
                                      )
                                  )
                              ),

                              Icon(Icons.info_outline,size: Constants.iconSize,)
                            ],
                          )
                      ),

                    ],
                  ),
                ),
              )
            ],
          ),
          Row(
            children: [
              Expanded(
                flex: 3,
                child:Row(
                  mainAxisAlignment: MainAxisAlignment.center,
                  crossAxisAlignment: CrossAxisAlignment.start,
                  children: [
                    Expanded(
                        flex: 3,
                        child: Container(
                            padding: const EdgeInsets.only(left: 10),
                            alignment:Alignment.topLeft,
                            child: Text(
                                "Taxivaxi",
                                style: GoogleFonts.lato(fontSize: Constants.subHeader)
                            )
                        )
                    ),
                    Expanded(
                        flex: 4,
                        child: Container(
                            alignment:Alignment.topLeft,
                            child: Text(
                                statusTv.toString(),
                                style: GoogleFonts.lato(
                                    textStyle: TextStyle(
                                        fontWeight: FontWeight.w600,
                                        fontSize: Constants.subHeader
                                    )
                                )
                            )
                        )
                    ),
                  ],
                ),
              ),
              Expanded(
                flex: 3,
                child: Row(
                  mainAxisAlignment: MainAxisAlignment.start,
                  crossAxisAlignment: CrossAxisAlignment.start,
                  children: [
                    Expanded(
                        flex: 3,
                        child: Container(
                            padding: const EdgeInsets.only(left: 10),
                            alignment:Alignment.topLeft,
                            child: Text(
                                "SPOC",
                                style: GoogleFonts.lato(fontSize: Constants.subHeader)
                            )
                        )),
                    Expanded(
                        flex: 4,
                        child: Container(
                            alignment:Alignment.topLeft,
                            child: Text(
                                userName.toString(),
                                overflow: TextOverflow.ellipsis,
                                style: GoogleFonts.lato(
                                    textStyle: TextStyle(
                                        fontWeight: FontWeight.w600,
                                        fontSize: Constants.subHeader
                                    )
                                )
                            )
                        )
                    )

                  ],
                ),
              ),

            ],
          ),
        ],
      ),
    ),
  );
}

==> booking_card_layout-0.0.5.tar.gz: lib/hotel_card_layout.dart <==
library booking_card_layout;

import 'package:booking_card_layout/constants.dart';
import 'package:booking_card_layout/tv_theme.dart';
import 'package:flutter/material.dart';
import 'package:flutter_phone_direct_caller/flutter_phone_direct_caller.dart';
import 'package:font_awesome_flutter/font_awesome_flutter.dart';
import 'package:google_fonts/google_fonts.dart';
import 'package:intl/intl.dart';

Widget HotelCardLayout(BuildContext context,String referenceNo,String city,String assCode,DateTime arrivalDatetime,DateTime depDatetime,String statusCompany,List<dynamic>people,String statusTv,String userName){
  showEmployeeDetails(){
    showDialog(context: context, builder: (BuildContext buContext){
      return AlertDialog(
        content: SizedBox(
          width: MediaQuery.of(context).size.width,
          height: 300,
          child: Column(
            children: [
              Row(
                mainAxisAlignment: MainAxisAlignment.spaceEvenly,
                children: [
                  Expanded(
                      flex: 5,
                      child: Container(
                          alignment: Alignment.center,
                          child: Text("Employee Details",style: GoogleFonts.lato(fontWeight: FontWeight.w700,fontSize: 20),))),
                  Expanded(
                    flex: 1,
                    child: Container(
                      alignment: Alignment.topRight,
                      child: IconButton(
                          onPressed: (){Navigator.pop(context);},
                          icon: const Icon(Icons.cancel_outlined)),
                    ),
                  ),
                ],
              ),
              SizedBox(
                height: 200,
                child: ListView.builder(
                    itemCount: people.length,
                    itemBuilder: (BuildContext context,int index){
                      return ListTile(
                        trailing: IconButton(
                          icon: const Icon(Icons.call,color: Colors.green,),
                          onPressed: ()async{
                            await FlutterPhoneDirectCaller.callNumber(people[index].peopleContact.toString());
                          },
                        ),
                        subtitle: Text("${people[index].peopleContact}"),
                        title: Text(people[index].peopleName!,style: GoogleFonts.lato(textStyle: const TextStyle(fontSize: 16,fontWeight: FontWeight.w600)),),
                      );
                    }
                ),
              )
            ],
          ),
        ),
      );
    });
  }
  return Container(
    padding: const EdgeInsets.all(2),
    child: Card(
      elevation: 5,
      surfaceTintColor: TVTheme.whiteColor,
      child: Column(
        crossAxisAlignment: CrossAxisAlignment.start,
        children: [
          Container(
            height: Constants.taxiCardTop,
            color: TVTheme.blackColor,
            child: Row(
              mainAxisAlignment: MainAxisAlignment.spaceBetween,
              children: [
                Padding(
                  padding: const EdgeInsets.only(left: 10),
                  child: Text(referenceNo.toString(),style: GoogleFonts.lato(fontWeight: FontWeight.w600,color: TVTheme.primaryColor,fontSize: Constants.subHeader),),
                ),
                Padding(
                  padding: const EdgeInsets.only(right: 10),
                  child: Text(city.toString(),style: GoogleFonts.lato(fontWeight: FontWeight.w600,color: TVTheme.primaryColor,fontSize: Constants.subHeader),),
                ),
              ],
            ),
          ),
          Padding(
            padding: const EdgeInsets.only(left: 10),
            child: Text("Assessment Code - ${assCode.toString()}",style: GoogleFonts.lato(fontWeight: FontWeight.w500,color: TVTheme.blackColor,fontSize: Constants.header)),
          ),
          const Divider(height: 2,),
          Row(
            children: [
              Expanded(
                  flex: 3,
                  child: Row(
                    children: [
                      Expanded(
                          flex: 3,
                          child: Column(
                            children: [
                              Icon(FontAwesomeIcons.hotel,size: Constants.iconSize,),
                              Text("Arrival",
                                style: GoogleFonts.lato(fontSize: Constants.subHeader),
                              ),
                            ],
                          )
                      ),
                      Expanded(
                        flex:5,
                        child: Column(
                          crossAxisAlignment: CrossAxisAlignment.start,
                          children: [
                            Text("${arrivalDatetime.day} ",style: GoogleFonts.lato(fontWeight: FontWeight.w600,fontSize: Constants.title),),
                            Text("${DateFormat.MMM().format(arrivalDatetime)} ${arrivalDatetime.year}",style: GoogleFonts.lato(fontSize: Constants.subHeader),),
                            Text(DateFormat.jm().format(arrivalDatetime),style: GoogleFonts.lato(fontSize: Constants.subHeader),),
                          ],
                        ),
                      ),
                    ],
                  )
              ),
              const SizedBox(width: 2,),
              Expanded(
                  flex: 3,
                  child: Row(
                    children: [
                      Expanded(
                          flex: 3,
                          child: Column(
                            children: [
                              Icon(FontAwesomeIcons.hotel,size: Constants.iconSize,),
                              Text("Departure",style: GoogleFonts.lato(fontSize: Constants.subHeader),),
                            ],
                          )
                      ),
                      Expanded(
                        flex:5,
                        child: Column(
                          crossAxisAlignment: CrossAxisAlignment.start,
                          children: [
                            Text("${depDatetime.day} ",style: GoogleFonts.lato(fontWeight: FontWeight.w600,fontSize: Constants.title),),
                            Text("${DateFormat.MMM(depDatetime)} ${depDatetime.year}",style: GoogleFonts.lato(fontSize: Constants.subHeader),),
                            Text(DateFormat.jm().format(depDatetime),style: GoogleFonts.lato(fontSize: Constants.subHeader),),
                          ],
                        ),
                      ),
                    ],
                  )
              ),
            ],
          ),
          const Divider(height: 2,),
          Row(
            children: [
              Expanded(
                flex: 3,
                child: Row(
                  mainAxisAlignment: MainAxisAlignment.start,
                  crossAxisAlignment: CrossAxisAlignment.start,
                  children: [
                    Expanded(
                        flex: 3,
                        child: Container(
                            padding: const EdgeInsets.only(left: 10),
                            alignment:Alignment.topLeft,
                            child: Text(
                                "Approver",
                                style: GoogleFonts.lato(fontSize: Constants.subHeader)
                            )
                        )),
                    Expanded(
                        flex: 4,
                        child: Container(
                            alignment:Alignment.topLeft,
                            child: Text(
                                statusCompany.toString(),
                                overflow: TextOverflow.ellipsis,
                                style: GoogleFonts.lato(
                                    textStyle: TextStyle(
                                        fontWeight: FontWeight.w600,
                                        fontSize: Constants.subHeader
                                    )
                                )
                            )
                        )
                    ),
                  ],
                ),
              ),

              Expanded(
                flex: 3,
                child:GestureDetector(
                  onTap: (){
                    showEmployeeDetails();
                  },
                  child: Row(
                    mainAxisAlignment: MainAxisAlignment.center,
                    crossAxisAlignment: CrossAxisAlignment.start,
                    children: [
                      Expanded(
                          flex: 3,
                          child: Container(
                              padding: const EdgeInsets.only(left: 10),
                              alignment:Alignment.topLeft,
                              child: Text(
                                  "People",
                                  style: GoogleFonts.lato(fontSize: Constants.subHeader)
                              )
                          )
                      ),
                      Expanded(
                          flex: 4,
                          child: Row(
                            children: [
                              Container(
                                  padding: const EdgeInsets.only(right: 5),
                                  alignment:Alignment.topLeft,
                                  child: Text(
                                      people.length.toString(),
                                      style: GoogleFonts.lato(fontSize: Constants.subHeader, fontWeight: FontWeight.w600
                                      )
                                  )
                              ),

                              Icon(Icons.info_outline,size: Constants.iconSize,)
                            ],
                          )
                      ),

                    ],
                  ),
                ),
              )
            ],
          ),
          Row(
            children: [
              Expanded(
                flex: 3,
                child:Row(
                  mainAxisAlignment: MainAxisAlignment.center,
                  crossAxisAlignment: CrossAxisAlignment.start,
                  children: [
                    Expanded(
                        flex: 3,
                        child: Container(
                            padding: const EdgeInsets.only(left: 10),
                            alignment:Alignment.topLeft,
                            child: Text(
                                "Taxivaxi",
                                style: GoogleFonts.lato(fontSize: Constants.subHeader)
                            )
                        )
                    ),
                    Expanded(
                        flex: 4,
                        child: Container(
                            alignment:Alignment.topLeft,
                            child: Text(
                                statusTv.toString(),
                                style: GoogleFonts.lato(
                                    textStyle: TextStyle(
                                        fontWeight: FontWeight.w600,
                                        fontSize: Constants.subHeader
                                    )
                                )
                            )
                        )
                    ),
                  ],
                ),
              ),
              Expanded(
                flex: 3,
                child: Row(
                  mainAxisAlignment: MainAxisAlignment.start,
                  crossAxisAlignment: CrossAxisAlignment.start,
                  children: [
                    Expanded(
                        flex: 3,
                        child: Container(
                            padding: const EdgeInsets.only(left: 10),
                            alignment:Alignment.topLeft,
                            child: Text(
                                "SPOC",
                                style: GoogleFonts.lato(fontSize: Constants.subHeader)
                            )
                        )),
                    Expanded(
                        flex: 4,
                        child: Container(
                            alignment:Alignment.topLeft,
                            child: Text(
                                userName.toString(),
                                overflow: TextOverflow.ellipsis,
                                style: GoogleFonts.lato(
                                    textStyle: TextStyle(
                                        fontWeight: FontWeight.w600,
                                        fontSize: Constants.subHeader
                                    )
                                )
                            )
                        )
                    )

                  ],
                ),
              ),

            ],
          ),
        ],
      ),
    ),
  );
}
